# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Webhook(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'events': 'list[str]',
        'name': 'str',
        'secret': 'str',
        'status': 'str',
        'url': 'str',
        'wh_id': 'str'
    }

    attribute_map = {
        'events': 'events',
        'name': 'name',
        'secret': 'secret',
        'status': 'status',
        'url': 'url',
        'wh_id': 'wh_id'
    }

    def __init__(self, events=None, name=None, secret=None, status=None, url=None, wh_id=None):  # noqa: E501
        """Webhook - a model defined in Swagger"""  # noqa: E501
        self._events = None
        self._name = None
        self._secret = None
        self._status = None
        self._url = None
        self._wh_id = None
        self.discriminator = None
        if events is not None:
            self.events = events
        if name is not None:
            self.name = name
        if secret is not None:
            self.secret = secret
        if status is not None:
            self.status = status
        if url is not None:
            self.url = url
        if wh_id is not None:
            self.wh_id = wh_id

    @property
    def events(self):
        """Gets the events of this Webhook.  # noqa: E501

        Tipo de evento manejado por el webhook. Para más referencia sobre los tipos de eventos soportados, revise la siguiente liga: <a href=\"#section/Eventos\">https://developers.wire4.mx/#section/Eventos.</a>  # noqa: E501

        :return: The events of this Webhook.  # noqa: E501
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this Webhook.

        Tipo de evento manejado por el webhook. Para más referencia sobre los tipos de eventos soportados, revise la siguiente liga: <a href=\"#section/Eventos\">https://developers.wire4.mx/#section/Eventos.</a>  # noqa: E501

        :param events: The events of this Webhook.  # noqa: E501
        :type: list[str]
        """

        self._events = events

    @property
    def name(self):
        """Gets the name of this Webhook.  # noqa: E501

        Es el nombre del webhook.  # noqa: E501

        :return: The name of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Webhook.

        Es el nombre del webhook.  # noqa: E501

        :param name: The name of this Webhook.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def secret(self):
        """Gets the secret of this Webhook.  # noqa: E501

        Es la llave con la que se debe de identificar que el webhook fue enviado por Wire4. Para mayor información revisar la guía de notificaciones en la sección de <a href=\"https://wire4.mx/#/guides/notificaciones\">\"Comprobación de firmas de Webhook\".</a>  # noqa: E501

        :return: The secret of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this Webhook.

        Es la llave con la que se debe de identificar que el webhook fue enviado por Wire4. Para mayor información revisar la guía de notificaciones en la sección de <a href=\"https://wire4.mx/#/guides/notificaciones\">\"Comprobación de firmas de Webhook\".</a>  # noqa: E501

        :param secret: The secret of this Webhook.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def status(self):
        """Gets the status of this Webhook.  # noqa: E501

        Estado (estatus) en el que se encuentra el webhook.  # noqa: E501

        :return: The status of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Webhook.

        Estado (estatus) en el que se encuentra el webhook.  # noqa: E501

        :param status: The status of this Webhook.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "DELETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def url(self):
        """Gets the url of this Webhook.  # noqa: E501

        Es la dirección URL a la que Wire4 enviará las notificaciones cuando un evento ocurra.  # noqa: E501

        :return: The url of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Webhook.

        Es la dirección URL a la que Wire4 enviará las notificaciones cuando un evento ocurra.  # noqa: E501

        :param url: The url of this Webhook.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def wh_id(self):
        """Gets the wh_id of this Webhook.  # noqa: E501

        Es el identificador del webhook.  # noqa: E501

        :return: The wh_id of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._wh_id

    @wh_id.setter
    def wh_id(self, wh_id):
        """Sets the wh_id of this Webhook.

        Es el identificador del webhook.  # noqa: E501

        :param wh_id: The wh_id of this Webhook.  # noqa: E501
        :type: str
        """

        self._wh_id = wh_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Webhook, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Webhook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TransactionOutgoingSpid(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'beneficiary_account': 'str',
        'cancel_return_url': 'str',
        'classification_id': 'str',
        'currency_code': 'str',
        'email': 'list[str]',
        'numeric_reference_spid': 'int',
        'order_id': 'str',
        'payment_concept_spid': 'str',
        'return_url': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'cancel_return_url': 'cancel_return_url',
        'classification_id': 'classification_id',
        'currency_code': 'currency_code',
        'email': 'email',
        'numeric_reference_spid': 'numeric_reference_spid',
        'order_id': 'order_id',
        'payment_concept_spid': 'payment_concept_spid',
        'return_url': 'return_url'
    }

    def __init__(self, amount=None, beneficiary_account=None, cancel_return_url=None, classification_id=None, currency_code=None, email=None, numeric_reference_spid=None, order_id=None, payment_concept_spid=None, return_url=None):  # noqa: E501
        """TransactionOutgoingSpid - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._beneficiary_account = None
        self._cancel_return_url = None
        self._classification_id = None
        self._currency_code = None
        self._email = None
        self._numeric_reference_spid = None
        self._order_id = None
        self._payment_concept_spid = None
        self._return_url = None
        self.discriminator = None
        self.amount = amount
        self.beneficiary_account = beneficiary_account
        self.cancel_return_url = cancel_return_url
        self.classification_id = classification_id
        self.currency_code = currency_code
        if email is not None:
            self.email = email
        self.numeric_reference_spid = numeric_reference_spid
        self.order_id = order_id
        self.payment_concept_spid = payment_concept_spid
        self.return_url = return_url

    @property
    def amount(self):
        """Gets the amount of this TransactionOutgoingSpid.  # noqa: E501

        Es el monto de la transferencia. Se valida que sean máximo 20 dígitos y 2 decimales. Ejemplo 1000.00  # noqa: E501

        :return: The amount of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TransactionOutgoingSpid.

        Es el monto de la transferencia. Se valida que sean máximo 20 dígitos y 2 decimales. Ejemplo 1000.00  # noqa: E501

        :param amount: The amount of this TransactionOutgoingSpid.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this TransactionOutgoingSpid.  # noqa: E501

        Cuenta del beneficiario, podría ser un número celular (10dígitos), tarjeta de débito (TDD) o Cuenta CLABE interbancaria (18 dígitos).   # noqa: E501

        :return: The beneficiary_account of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this TransactionOutgoingSpid.

        Cuenta del beneficiario, podría ser un número celular (10dígitos), tarjeta de débito (TDD) o Cuenta CLABE interbancaria (18 dígitos).   # noqa: E501

        :param beneficiary_account: The beneficiary_account of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def cancel_return_url(self):
        """Gets the cancel_return_url of this TransactionOutgoingSpid.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de que el usario cancele el registro.  # noqa: E501

        :return: The cancel_return_url of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._cancel_return_url

    @cancel_return_url.setter
    def cancel_return_url(self, cancel_return_url):
        """Sets the cancel_return_url of this TransactionOutgoingSpid.

        Es la dirección URL a la que se redirigirá en caso de que el usario cancele el registro.  # noqa: E501

        :param cancel_return_url: The cancel_return_url of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if cancel_return_url is None:
            raise ValueError("Invalid value for `cancel_return_url`, must not be `None`")  # noqa: E501

        self._cancel_return_url = cancel_return_url

    @property
    def classification_id(self):
        """Gets the classification_id of this TransactionOutgoingSpid.  # noqa: E501

        Es el identificador de la clasificación de la transferencia SPID.  # noqa: E501

        :return: The classification_id of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._classification_id

    @classification_id.setter
    def classification_id(self, classification_id):
        """Sets the classification_id of this TransactionOutgoingSpid.

        Es el identificador de la clasificación de la transferencia SPID.  # noqa: E501

        :param classification_id: The classification_id of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if classification_id is None:
            raise ValueError("Invalid value for `classification_id`, must not be `None`")  # noqa: E501

        self._classification_id = classification_id

    @property
    def currency_code(self):
        """Gets the currency_code of this TransactionOutgoingSpid.  # noqa: E501

        Código de moneda en la que opera la cuenta.  # noqa: E501

        :return: The currency_code of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this TransactionOutgoingSpid.

        Código de moneda en la que opera la cuenta.  # noqa: E501

        :param currency_code: The currency_code of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if currency_code is None:
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def email(self):
        """Gets the email of this TransactionOutgoingSpid.  # noqa: E501

        Lista de correo electrónico (email) del beneficiario. Este campo es opcional.  # noqa: E501

        :return: The email of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TransactionOutgoingSpid.

        Lista de correo electrónico (email) del beneficiario. Este campo es opcional.  # noqa: E501

        :param email: The email of this TransactionOutgoingSpid.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def numeric_reference_spid(self):
        """Gets the numeric_reference_spid of this TransactionOutgoingSpid.  # noqa: E501

        Es la referencia numérica de la transferencia.  # noqa: E501

        :return: The numeric_reference_spid of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: int
        """
        return self._numeric_reference_spid

    @numeric_reference_spid.setter
    def numeric_reference_spid(self, numeric_reference_spid):
        """Sets the numeric_reference_spid of this TransactionOutgoingSpid.

        Es la referencia numérica de la transferencia.  # noqa: E501

        :param numeric_reference_spid: The numeric_reference_spid of this TransactionOutgoingSpid.  # noqa: E501
        :type: int
        """
        if numeric_reference_spid is None:
            raise ValueError("Invalid value for `numeric_reference_spid`, must not be `None`")  # noqa: E501

        self._numeric_reference_spid = numeric_reference_spid

    @property
    def order_id(self):
        """Gets the order_id of this TransactionOutgoingSpid.  # noqa: E501

        Es la referencia de la transferencia asignada por el cliente. Ejemplo: dae9c6ae-8c7a-42e8-99f4-ebe90566efae  # noqa: E501

        :return: The order_id of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this TransactionOutgoingSpid.

        Es la referencia de la transferencia asignada por el cliente. Ejemplo: dae9c6ae-8c7a-42e8-99f4-ebe90566efae  # noqa: E501

        :param order_id: The order_id of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if order_id is None:
            raise ValueError("Invalid value for `order_id`, must not be `None`")  # noqa: E501

        self._order_id = order_id

    @property
    def payment_concept_spid(self):
        """Gets the payment_concept_spid of this TransactionOutgoingSpid.  # noqa: E501

        Es el concepto de la transferencia.  # noqa: E501

        :return: The payment_concept_spid of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._payment_concept_spid

    @payment_concept_spid.setter
    def payment_concept_spid(self, payment_concept_spid):
        """Sets the payment_concept_spid of this TransactionOutgoingSpid.

        Es el concepto de la transferencia.  # noqa: E501

        :param payment_concept_spid: The payment_concept_spid of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if payment_concept_spid is None:
            raise ValueError("Invalid value for `payment_concept_spid`, must not be `None`")  # noqa: E501

        self._payment_concept_spid = payment_concept_spid

    @property
    def return_url(self):
        """Gets the return_url of this TransactionOutgoingSpid.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de éxito.  # noqa: E501

        :return: The return_url of this TransactionOutgoingSpid.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this TransactionOutgoingSpid.

        Es la dirección URL a la que se redirigirá en caso de éxito.  # noqa: E501

        :param return_url: The return_url of this TransactionOutgoingSpid.  # noqa: E501
        :type: str
        """
        if return_url is None:
            raise ValueError("Invalid value for `return_url`, must not be `None`")  # noqa: E501

        self._return_url = return_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TransactionOutgoingSpid, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionOutgoingSpid):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Depositant(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias': 'str',
        'currency_code': 'str',
        'depositant_clabe': 'str',
        'email': 'list[str]',
        'name': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'currency_code': 'currency_code',
        'depositant_clabe': 'depositant_clabe',
        'email': 'email',
        'name': 'name'
    }

    def __init__(self, alias=None, currency_code=None, depositant_clabe=None, email=None, name=None):  # noqa: E501
        """Depositant - a model defined in Swagger"""  # noqa: E501
        self._alias = None
        self._currency_code = None
        self._depositant_clabe = None
        self._email = None
        self._name = None
        self.discriminator = None
        if alias is not None:
            self.alias = alias
        if currency_code is not None:
            self.currency_code = currency_code
        if depositant_clabe is not None:
            self.depositant_clabe = depositant_clabe
        if email is not None:
            self.email = email
        if name is not None:
            self.name = name

    @property
    def alias(self):
        """Gets the alias of this Depositant.  # noqa: E501

        Es el alias del depositante.  # noqa: E501

        :return: The alias of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this Depositant.

        Es el alias del depositante.  # noqa: E501

        :param alias: The alias of this Depositant.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def currency_code(self):
        """Gets the currency_code of this Depositant.  # noqa: E501

        Es el código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos. Sólo se permiten los valores <b>MXP</b> y <b>USD</b>.  # noqa: E501

        :return: The currency_code of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Depositant.

        Es el código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos. Sólo se permiten los valores <b>MXP</b> y <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this Depositant.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def depositant_clabe(self):
        """Gets the depositant_clabe of this Depositant.  # noqa: E501

        Es la cuenta CLABE (es de 18 dígitos) del depositante.  # noqa: E501

        :return: The depositant_clabe of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._depositant_clabe

    @depositant_clabe.setter
    def depositant_clabe(self, depositant_clabe):
        """Sets the depositant_clabe of this Depositant.

        Es la cuenta CLABE (es de 18 dígitos) del depositante.  # noqa: E501

        :param depositant_clabe: The depositant_clabe of this Depositant.  # noqa: E501
        :type: str
        """

        self._depositant_clabe = depositant_clabe

    @property
    def email(self):
        """Gets the email of this Depositant.  # noqa: E501

        Es la lista de correos electrónicos (emails) del depositante.  # noqa: E501

        :return: The email of this Depositant.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Depositant.

        Es la lista de correos electrónicos (emails) del depositante.  # noqa: E501

        :param email: The email of this Depositant.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def name(self):
        """Gets the name of this Depositant.  # noqa: E501

        Es el nombre del depositante.  # noqa: E501

        :return: The name of this Depositant.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Depositant.

        Es el nombre del depositante.  # noqa: E501

        :param name: The name of this Depositant.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Depositant, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Depositant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.message_institution import MessageInstitution  # noqa: F401,E501


class MessagePaymentStatePending(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account': 'str',
        'amount': 'float',
        'beneficiary_account': 'str',
        'beneficiary_bank': 'MessageInstitution',
        'beneficiary_name': 'str',
        'concept': 'str',
        'currency_code': 'str',
        'detention_message': 'str',
        'error_message': 'str',
        'order_id': 'str',
        'payment_order_id': 'int',
        'pending_reason': 'str',
        'reference': 'int',
        'request_id': 'str',
        'status_code': 'str',
        'transaction_id': 'int'
    }

    attribute_map = {
        'account': 'account',
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'beneficiary_bank': 'beneficiary_bank',
        'beneficiary_name': 'beneficiary_name',
        'concept': 'concept',
        'currency_code': 'currency_code',
        'detention_message': 'detention_message',
        'error_message': 'error_message',
        'order_id': 'order_id',
        'payment_order_id': 'payment_order_id',
        'pending_reason': 'pending_reason',
        'reference': 'reference',
        'request_id': 'request_id',
        'status_code': 'status_code',
        'transaction_id': 'transaction_id'
    }

    def __init__(self, account=None, amount=None, beneficiary_account=None, beneficiary_bank=None, beneficiary_name=None, concept=None, currency_code=None, detention_message=None, error_message=None, order_id=None, payment_order_id=None, pending_reason=None, reference=None, request_id=None, status_code=None, transaction_id=None):  # noqa: E501
        """MessagePaymentStatePending - a model defined in Swagger"""  # noqa: E501
        self._account = None
        self._amount = None
        self._beneficiary_account = None
        self._beneficiary_bank = None
        self._beneficiary_name = None
        self._concept = None
        self._currency_code = None
        self._detention_message = None
        self._error_message = None
        self._order_id = None
        self._payment_order_id = None
        self._pending_reason = None
        self._reference = None
        self._request_id = None
        self._status_code = None
        self._transaction_id = None
        self.discriminator = None
        if account is not None:
            self.account = account
        if amount is not None:
            self.amount = amount
        if beneficiary_account is not None:
            self.beneficiary_account = beneficiary_account
        if beneficiary_bank is not None:
            self.beneficiary_bank = beneficiary_bank
        if beneficiary_name is not None:
            self.beneficiary_name = beneficiary_name
        if concept is not None:
            self.concept = concept
        if currency_code is not None:
            self.currency_code = currency_code
        if detention_message is not None:
            self.detention_message = detention_message
        if error_message is not None:
            self.error_message = error_message
        if order_id is not None:
            self.order_id = order_id
        if payment_order_id is not None:
            self.payment_order_id = payment_order_id
        if pending_reason is not None:
            self.pending_reason = pending_reason
        if reference is not None:
            self.reference = reference
        if request_id is not None:
            self.request_id = request_id
        if status_code is not None:
            self.status_code = status_code
        if transaction_id is not None:
            self.transaction_id = transaction_id

    @property
    def account(self):
        """Gets the account of this MessagePaymentStatePending.  # noqa: E501

        Es la cuenta del ordenante.  # noqa: E501

        :return: The account of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this MessagePaymentStatePending.

        Es la cuenta del ordenante.  # noqa: E501

        :param account: The account of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def amount(self):
        """Gets the amount of this MessagePaymentStatePending.  # noqa: E501

        Es el monto de la transferencia.  # noqa: E501

        :return: The amount of this MessagePaymentStatePending.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this MessagePaymentStatePending.

        Es el monto de la transferencia.  # noqa: E501

        :param amount: The amount of this MessagePaymentStatePending.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this MessagePaymentStatePending.  # noqa: E501

        Es la cuenta del beneficiario.  # noqa: E501

        :return: The beneficiary_account of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this MessagePaymentStatePending.

        Es la cuenta del beneficiario.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._beneficiary_account = beneficiary_account

    @property
    def beneficiary_bank(self):
        """Gets the beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501


        :return: The beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501
        :rtype: MessageInstitution
        """
        return self._beneficiary_bank

    @beneficiary_bank.setter
    def beneficiary_bank(self, beneficiary_bank):
        """Sets the beneficiary_bank of this MessagePaymentStatePending.


        :param beneficiary_bank: The beneficiary_bank of this MessagePaymentStatePending.  # noqa: E501
        :type: MessageInstitution
        """

        self._beneficiary_bank = beneficiary_bank

    @property
    def beneficiary_name(self):
        """Gets the beneficiary_name of this MessagePaymentStatePending.  # noqa: E501

        Es el nombre del beneficiario.  # noqa: E501

        :return: The beneficiary_name of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, beneficiary_name):
        """Sets the beneficiary_name of this MessagePaymentStatePending.

        Es el nombre del beneficiario.  # noqa: E501

        :param beneficiary_name: The beneficiary_name of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._beneficiary_name = beneficiary_name

    @property
    def concept(self):
        """Gets the concept of this MessagePaymentStatePending.  # noqa: E501

        Es el concepto de la transferencia de salida.  # noqa: E501

        :return: The concept of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this MessagePaymentStatePending.

        Es el concepto de la transferencia de salida.  # noqa: E501

        :param concept: The concept of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._concept = concept

    @property
    def currency_code(self):
        """Gets the currency_code of this MessagePaymentStatePending.  # noqa: E501

        Código de divisa de la transferencia de salida. Es en el formato estándar ISO 4217 y es de 3 dígitos. Ejemplo: \"MXN\".  # noqa: E501

        :return: The currency_code of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this MessagePaymentStatePending.

        Código de divisa de la transferencia de salida. Es en el formato estándar ISO 4217 y es de 3 dígitos. Ejemplo: \"MXN\".  # noqa: E501

        :param currency_code: The currency_code of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def detention_message(self):
        """Gets the detention_message of this MessagePaymentStatePending.  # noqa: E501

        Es el Mensaje de detención de Monex, indica la causa por la cuál esta detenida la operación en Monex.  # noqa: E501

        :return: The detention_message of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._detention_message

    @detention_message.setter
    def detention_message(self, detention_message):
        """Sets the detention_message of this MessagePaymentStatePending.

        Es el Mensaje de detención de Monex, indica la causa por la cuál esta detenida la operación en Monex.  # noqa: E501

        :param detention_message: The detention_message of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._detention_message = detention_message

    @property
    def error_message(self):
        """Gets the error_message of this MessagePaymentStatePending.  # noqa: E501

        Es el mensaje de error.  # noqa: E501

        :return: The error_message of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this MessagePaymentStatePending.

        Es el mensaje de error.  # noqa: E501

        :param error_message: The error_message of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def order_id(self):
        """Gets the order_id of this MessagePaymentStatePending.  # noqa: E501

        El identificador de la transferencia de salida.  # noqa: E501

        :return: The order_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this MessagePaymentStatePending.

        El identificador de la transferencia de salida.  # noqa: E501

        :param order_id: The order_id of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_order_id(self):
        """Gets the payment_order_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador de la orden de pago de Monex de la transferencia de salida.  # noqa: E501

        :return: The payment_order_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._payment_order_id

    @payment_order_id.setter
    def payment_order_id(self, payment_order_id):
        """Sets the payment_order_id of this MessagePaymentStatePending.

        Es el identificador de la orden de pago de Monex de la transferencia de salida.  # noqa: E501

        :param payment_order_id: The payment_order_id of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._payment_order_id = payment_order_id

    @property
    def pending_reason(self):
        """Gets the pending_reason of this MessagePaymentStatePending.  # noqa: E501

        Es el esaado que identifica la causa por la que la transferencia se ecuentra detenida o  pendiente de procesarse. Los posibles estados son: <ul><li>FI=Fondos Insuficientes</li><li>FM=Firma mancomunada, en espera de ingreso de segundo token de autorización</li><li>DP=Se detecto una transferencia duplicada que esta en wspera de confirmación o de eliminación</li></ul>  # noqa: E501

        :return: The pending_reason of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._pending_reason

    @pending_reason.setter
    def pending_reason(self, pending_reason):
        """Sets the pending_reason of this MessagePaymentStatePending.

        Es el esaado que identifica la causa por la que la transferencia se ecuentra detenida o  pendiente de procesarse. Los posibles estados son: <ul><li>FI=Fondos Insuficientes</li><li>FM=Firma mancomunada, en espera de ingreso de segundo token de autorización</li><li>DP=Se detecto una transferencia duplicada que esta en wspera de confirmación o de eliminación</li></ul>  # noqa: E501

        :param pending_reason: The pending_reason of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._pending_reason = pending_reason

    @property
    def reference(self):
        """Gets the reference of this MessagePaymentStatePending.  # noqa: E501

        Es la referecia de la transferencia.  # noqa: E501

        :return: The reference of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this MessagePaymentStatePending.

        Es la referecia de la transferencia.  # noqa: E501

        :param reference: The reference of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._reference = reference

    @property
    def request_id(self):
        """Gets the request_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador, en esta API, de la petición de envío de la transferencia de salida.  # noqa: E501

        :return: The request_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this MessagePaymentStatePending.

        Es el identificador, en esta API, de la petición de envío de la transferencia de salida.  # noqa: E501

        :param request_id: The request_id of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def status_code(self):
        """Gets the status_code of this MessagePaymentStatePending.  # noqa: E501

        Es el estado (estatus) de la transferencia de salida. Deberá ser \"PENDING\".  # noqa: E501

        :return: The status_code of this MessagePaymentStatePending.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this MessagePaymentStatePending.

        Es el estado (estatus) de la transferencia de salida. Deberá ser \"PENDING\".  # noqa: E501

        :param status_code: The status_code of this MessagePaymentStatePending.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def transaction_id(self):
        """Gets the transaction_id of this MessagePaymentStatePending.  # noqa: E501

        Es el identificador de Monex de la transferencia de salida, podría no estar presente por lo que Usted debería hacer referencias mediate el paymentOrderID.  # noqa: E501

        :return: The transaction_id of this MessagePaymentStatePending.  # noqa: E501
        :rtype: int
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this MessagePaymentStatePending.

        Es el identificador de Monex de la transferencia de salida, podría no estar presente por lo que Usted debería hacer referencias mediate el paymentOrderID.  # noqa: E501

        :param transaction_id: The transaction_id of this MessagePaymentStatePending.  # noqa: E501
        :type: int
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessagePaymentStatePending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessagePaymentStatePending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.compay import Compay  # noqa: F401,E501
from wire4_client.models.payment_codi import PaymentCODI  # noqa: F401,E501
from wire4_client.models.sales_point import SalesPoint  # noqa: F401,E501


class Operations(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'company': 'Compay',
        'description': 'str',
        'due_date': 'datetime',
        'order_id': 'str',
        'payment': 'PaymentCODI',
        'phone_number': 'str',
        'sales_point': 'SalesPoint',
        'status': 'str',
        'type': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'company': 'company',
        'description': 'description',
        'due_date': 'due_date',
        'order_id': 'order_id',
        'payment': 'payment',
        'phone_number': 'phone_number',
        'sales_point': 'sales_point',
        'status': 'status',
        'type': 'type'
    }

    def __init__(self, amount=None, company=None, description=None, due_date=None, order_id=None, payment=None, phone_number=None, sales_point=None, status=None, type=None):  # noqa: E501
        """Operations - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._company = None
        self._description = None
        self._due_date = None
        self._order_id = None
        self._payment = None
        self._phone_number = None
        self._sales_point = None
        self._status = None
        self._type = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if company is not None:
            self.company = company
        if description is not None:
            self.description = description
        if due_date is not None:
            self.due_date = due_date
        if order_id is not None:
            self.order_id = order_id
        if payment is not None:
            self.payment = payment
        if phone_number is not None:
            self.phone_number = phone_number
        if sales_point is not None:
            self.sales_point = sales_point
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type

    @property
    def amount(self):
        """Gets the amount of this Operations.  # noqa: E501

        Es el monto de la petición.  # noqa: E501

        :return: The amount of this Operations.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Operations.

        Es el monto de la petición.  # noqa: E501

        :param amount: The amount of this Operations.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def company(self):
        """Gets the company of this Operations.  # noqa: E501


        :return: The company of this Operations.  # noqa: E501
        :rtype: Compay
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this Operations.


        :param company: The company of this Operations.  # noqa: E501
        :type: Compay
        """

        self._company = company

    @property
    def description(self):
        """Gets the description of this Operations.  # noqa: E501

        Es la descripción de la petición.  # noqa: E501

        :return: The description of this Operations.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Operations.

        Es la descripción de la petición.  # noqa: E501

        :param description: The description of this Operations.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def due_date(self):
        """Gets the due_date of this Operations.  # noqa: E501

        Fecha de vencimiento de la petición  # noqa: E501

        :return: The due_date of this Operations.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this Operations.

        Fecha de vencimiento de la petición  # noqa: E501

        :param due_date: The due_date of this Operations.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def order_id(self):
        """Gets the order_id of this Operations.  # noqa: E501

        Es el order id de la petición.  # noqa: E501

        :return: The order_id of this Operations.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this Operations.

        Es el order id de la petición.  # noqa: E501

        :param order_id: The order_id of this Operations.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment(self):
        """Gets the payment of this Operations.  # noqa: E501


        :return: The payment of this Operations.  # noqa: E501
        :rtype: PaymentCODI
        """
        return self._payment

    @payment.setter
    def payment(self, payment):
        """Sets the payment of this Operations.


        :param payment: The payment of this Operations.  # noqa: E501
        :type: PaymentCODI
        """

        self._payment = payment

    @property
    def phone_number(self):
        """Gets the phone_number of this Operations.  # noqa: E501

        Es el número de teléfono.  # noqa: E501

        :return: The phone_number of this Operations.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this Operations.

        Es el número de teléfono.  # noqa: E501

        :param phone_number: The phone_number of this Operations.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def sales_point(self):
        """Gets the sales_point of this Operations.  # noqa: E501


        :return: The sales_point of this Operations.  # noqa: E501
        :rtype: SalesPoint
        """
        return self._sales_point

    @sales_point.setter
    def sales_point(self, sales_point):
        """Sets the sales_point of this Operations.


        :param sales_point: The sales_point of this Operations.  # noqa: E501
        :type: SalesPoint
        """

        self._sales_point = sales_point

    @property
    def status(self):
        """Gets the status of this Operations.  # noqa: E501

        Estatus de la petición  # noqa: E501

        :return: The status of this Operations.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Operations.

        Estatus de la petición  # noqa: E501

        :param status: The status of this Operations.  # noqa: E501
        :type: str
        """
        allowed_values = ["RECEIVED", "COMPLETED", "CANCELLED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def type(self):
        """Gets the type of this Operations.  # noqa: E501

        Es el tipo de petición de cobro.  # noqa: E501

        :return: The type of this Operations.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Operations.

        Es el tipo de petición de cobro.  # noqa: E501

        :param type: The type of this Operations.  # noqa: E501
        :type: str
        """
        allowed_values = ["PUSH_NOTIFICATION", "QR_CODE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Operations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Operations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CepSearchBanxico(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'beneficiary_account': 'str',
        'beneficiary_bank_key': 'str',
        'clave_rastreo': 'str',
        'operation_date': 'str',
        'reference': 'str',
        'sender_account': 'str',
        'sender_bank_key': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'beneficiary_bank_key': 'beneficiary_bank_key',
        'clave_rastreo': 'clave_rastreo',
        'operation_date': 'operation_date',
        'reference': 'reference',
        'sender_account': 'sender_account',
        'sender_bank_key': 'sender_bank_key'
    }

    def __init__(self, amount=None, beneficiary_account=None, beneficiary_bank_key=None, clave_rastreo=None, operation_date=None, reference=None, sender_account=None, sender_bank_key=None):  # noqa: E501
        """CepSearchBanxico - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._beneficiary_account = None
        self._beneficiary_bank_key = None
        self._clave_rastreo = None
        self._operation_date = None
        self._reference = None
        self._sender_account = None
        self._sender_bank_key = None
        self.discriminator = None
        self.amount = amount
        self.beneficiary_account = beneficiary_account
        if beneficiary_bank_key is not None:
            self.beneficiary_bank_key = beneficiary_bank_key
        self.clave_rastreo = clave_rastreo
        self.operation_date = operation_date
        if reference is not None:
            self.reference = reference
        if sender_account is not None:
            self.sender_account = sender_account
        if sender_bank_key is not None:
            self.sender_bank_key = sender_bank_key

    @property
    def amount(self):
        """Gets the amount of this CepSearchBanxico.  # noqa: E501

        Es el monto de la transferencia. Ejemplo 1000.00  # noqa: E501

        :return: The amount of this CepSearchBanxico.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CepSearchBanxico.

        Es el monto de la transferencia. Ejemplo 1000.00  # noqa: E501

        :param amount: The amount of this CepSearchBanxico.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this CepSearchBanxico.  # noqa: E501

        Es la cuenta de beneficiario.  # noqa: E501

        :return: The beneficiary_account of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this CepSearchBanxico.

        Es la cuenta de beneficiario.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this CepSearchBanxico.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def beneficiary_bank_key(self):
        """Gets the beneficiary_bank_key of this CepSearchBanxico.  # noqa: E501

        Clave del banco beneficiario. Éste valor no esta presente si obtiene de la cuenta del beneficiario, en caso de que sea un número celular éste campo es requerido. se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The beneficiary_bank_key of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_bank_key

    @beneficiary_bank_key.setter
    def beneficiary_bank_key(self, beneficiary_bank_key):
        """Sets the beneficiary_bank_key of this CepSearchBanxico.

        Clave del banco beneficiario. Éste valor no esta presente si obtiene de la cuenta del beneficiario, en caso de que sea un número celular éste campo es requerido. se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param beneficiary_bank_key: The beneficiary_bank_key of this CepSearchBanxico.  # noqa: E501
        :type: str
        """

        self._beneficiary_bank_key = beneficiary_bank_key

    @property
    def clave_rastreo(self):
        """Gets the clave_rastreo of this CepSearchBanxico.  # noqa: E501

        Es la clave de rastreo de la transferencia.  # noqa: E501

        :return: The clave_rastreo of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._clave_rastreo

    @clave_rastreo.setter
    def clave_rastreo(self, clave_rastreo):
        """Sets the clave_rastreo of this CepSearchBanxico.

        Es la clave de rastreo de la transferencia.  # noqa: E501

        :param clave_rastreo: The clave_rastreo of this CepSearchBanxico.  # noqa: E501
        :type: str
        """
        if clave_rastreo is None:
            raise ValueError("Invalid value for `clave_rastreo`, must not be `None`")  # noqa: E501

        self._clave_rastreo = clave_rastreo

    @property
    def operation_date(self):
        """Gets the operation_date of this CepSearchBanxico.  # noqa: E501

        Es la fecha de operación de la transferencia, formato: dd-MM-yyyy.  # noqa: E501

        :return: The operation_date of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this CepSearchBanxico.

        Es la fecha de operación de la transferencia, formato: dd-MM-yyyy.  # noqa: E501

        :param operation_date: The operation_date of this CepSearchBanxico.  # noqa: E501
        :type: str
        """
        if operation_date is None:
            raise ValueError("Invalid value for `operation_date`, must not be `None`")  # noqa: E501

        self._operation_date = operation_date

    @property
    def reference(self):
        """Gets the reference of this CepSearchBanxico.  # noqa: E501

        Es la referencia numérica de la transferencia. Se valida hasta 7 dígitos.  # noqa: E501

        :return: The reference of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CepSearchBanxico.

        Es la referencia numérica de la transferencia. Se valida hasta 7 dígitos.  # noqa: E501

        :param reference: The reference of this CepSearchBanxico.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sender_account(self):
        """Gets the sender_account of this CepSearchBanxico.  # noqa: E501

        Es la cuenta ordenante, es requerida cuando se no se envía la clave del banco ordenante.  # noqa: E501

        :return: The sender_account of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._sender_account

    @sender_account.setter
    def sender_account(self, sender_account):
        """Sets the sender_account of this CepSearchBanxico.

        Es la cuenta ordenante, es requerida cuando se no se envía la clave del banco ordenante.  # noqa: E501

        :param sender_account: The sender_account of this CepSearchBanxico.  # noqa: E501
        :type: str
        """

        self._sender_account = sender_account

    @property
    def sender_bank_key(self):
        """Gets the sender_bank_key of this CepSearchBanxico.  # noqa: E501

        Es la clave del banco ordenante, es requerida cuando no se envía la cuenta ordenante.  Se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :return: The sender_bank_key of this CepSearchBanxico.  # noqa: E501
        :rtype: str
        """
        return self._sender_bank_key

    @sender_bank_key.setter
    def sender_bank_key(self, sender_bank_key):
        """Sets the sender_bank_key of this CepSearchBanxico.

        Es la clave del banco ordenante, es requerida cuando no se envía la cuenta ordenante.  Se puede obtener del recurso de las <a href=\"#operation/getAllInstitutionsUsingGET\">instituciones.</a>  # noqa: E501

        :param sender_bank_key: The sender_bank_key of this CepSearchBanxico.  # noqa: E501
        :type: str
        """

        self._sender_bank_key = sender_bank_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CepSearchBanxico, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CepSearchBanxico):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.operations import Operations  # noqa: F401,E501


class PagerResponseDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'list[Operations]',
        'number_of_elements': 'int',
        'page': 'int',
        'size': 'int',
        'total_items': 'int',
        'total_pages': 'int'
    }

    attribute_map = {
        'content': 'content',
        'number_of_elements': 'number_of_elements',
        'page': 'page',
        'size': 'size',
        'total_items': 'total_items',
        'total_pages': 'total_pages'
    }

    def __init__(self, content=None, number_of_elements=None, page=None, size=None, total_items=None, total_pages=None):  # noqa: E501
        """PagerResponseDto - a model defined in Swagger"""  # noqa: E501
        self._content = None
        self._number_of_elements = None
        self._page = None
        self._size = None
        self._total_items = None
        self._total_pages = None
        self.discriminator = None
        if content is not None:
            self.content = content
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if page is not None:
            self.page = page
        if size is not None:
            self.size = size
        if total_items is not None:
            self.total_items = total_items
        if total_pages is not None:
            self.total_pages = total_pages

    @property
    def content(self):
        """Gets the content of this PagerResponseDto.  # noqa: E501

        Es el contenido de la respuesta paginada.  # noqa: E501

        :return: The content of this PagerResponseDto.  # noqa: E501
        :rtype: list[Operations]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PagerResponseDto.

        Es el contenido de la respuesta paginada.  # noqa: E501

        :param content: The content of this PagerResponseDto.  # noqa: E501
        :type: list[Operations]
        """

        self._content = content

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PagerResponseDto.  # noqa: E501

        Es el número de elementos en la página actual.  # noqa: E501

        :return: The number_of_elements of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PagerResponseDto.

        Es el número de elementos en la página actual.  # noqa: E501

        :param number_of_elements: The number_of_elements of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def page(self):
        """Gets the page of this PagerResponseDto.  # noqa: E501

        Es el número de página.  # noqa: E501

        :return: The page of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this PagerResponseDto.

        Es el número de página.  # noqa: E501

        :param page: The page of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def size(self):
        """Gets the size of this PagerResponseDto.  # noqa: E501

        Es el tamaño de la página, por ejemplo puede ser 20, que significa que son 20 registros por página.  # noqa: E501

        :return: The size of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PagerResponseDto.

        Es el tamaño de la página, por ejemplo puede ser 20, que significa que son 20 registros por página.  # noqa: E501

        :param size: The size of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def total_items(self):
        """Gets the total_items of this PagerResponseDto.  # noqa: E501

        Es el número total de elementos de la consulta.  # noqa: E501

        :return: The total_items of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._total_items

    @total_items.setter
    def total_items(self, total_items):
        """Sets the total_items of this PagerResponseDto.

        Es el número total de elementos de la consulta.  # noqa: E501

        :param total_items: The total_items of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._total_items = total_items

    @property
    def total_pages(self):
        """Gets the total_pages of this PagerResponseDto.  # noqa: E501

        Es el número total de paginas.  # noqa: E501

        :return: The total_pages of this PagerResponseDto.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PagerResponseDto.

        Es el número total de paginas.  # noqa: E501

        :param total_pages: The total_pages of this PagerResponseDto.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PagerResponseDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PagerResponseDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SalesPointRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_ip': 'str',
        'account': 'str',
        'name': 'str',
        'notifications_url': 'str'
    }

    attribute_map = {
        'access_ip': 'access_ip',
        'account': 'account',
        'name': 'name',
        'notifications_url': 'notifications_url'
    }

    def __init__(self, access_ip=None, account=None, name=None, notifications_url=None):  # noqa: E501
        """SalesPointRequest - a model defined in Swagger"""  # noqa: E501
        self._access_ip = None
        self._account = None
        self._name = None
        self._notifications_url = None
        self.discriminator = None
        self.access_ip = access_ip
        self.account = account
        self.name = name
        self.notifications_url = notifications_url

    @property
    def access_ip(self):
        """Gets the access_ip of this SalesPointRequest.  # noqa: E501

        Es la dirección IP desde donde se recibirán las peticiones de este punto de venta  # noqa: E501

        :return: The access_ip of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._access_ip

    @access_ip.setter
    def access_ip(self, access_ip):
        """Sets the access_ip of this SalesPointRequest.

        Es la dirección IP desde donde se recibirán las peticiones de este punto de venta  # noqa: E501

        :param access_ip: The access_ip of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if access_ip is None:
            raise ValueError("Invalid value for `access_ip`, must not be `None`")  # noqa: E501

        self._access_ip = access_ip

    @property
    def account(self):
        """Gets the account of this SalesPointRequest.  # noqa: E501

        Es el número de cuenta CLABE donde se realizará el deposito del cobro CODI®.  # noqa: E501

        :return: The account of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this SalesPointRequest.

        Es el número de cuenta CLABE donde se realizará el deposito del cobro CODI®.  # noqa: E501

        :param account: The account of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if account is None:
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501

        self._account = account

    @property
    def name(self):
        """Gets the name of this SalesPointRequest.  # noqa: E501

        Es el nombre del punto de venta.  # noqa: E501

        :return: The name of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SalesPointRequest.

        Es el nombre del punto de venta.  # noqa: E501

        :param name: The name of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def notifications_url(self):
        """Gets the notifications_url of this SalesPointRequest.  # noqa: E501

        Es la dirección URL para envíar notificaciones CODI® al punto de venta.  # noqa: E501

        :return: The notifications_url of this SalesPointRequest.  # noqa: E501
        :rtype: str
        """
        return self._notifications_url

    @notifications_url.setter
    def notifications_url(self, notifications_url):
        """Sets the notifications_url of this SalesPointRequest.

        Es la dirección URL para envíar notificaciones CODI® al punto de venta.  # noqa: E501

        :param notifications_url: The notifications_url of this SalesPointRequest.  # noqa: E501
        :type: str
        """
        if notifications_url is None:
            raise ValueError("Invalid value for `notifications_url`, must not be `None`")  # noqa: E501

        self._notifications_url = notifications_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesPointRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesPointRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.address_company import AddressCompany  # noqa: F401,E501


class AccountDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'AddressCompany',
        'business_name': 'str',
        'constitution_date': 'str',
        'emails': 'list[str]',
        'legal_representatives': 'list[str]',
        'rfc': 'str'
    }

    attribute_map = {
        'address': 'address',
        'business_name': 'business_name',
        'constitution_date': 'constitution_date',
        'emails': 'emails',
        'legal_representatives': 'legal_representatives',
        'rfc': 'rfc'
    }

    def __init__(self, address=None, business_name=None, constitution_date=None, emails=None, legal_representatives=None, rfc=None):  # noqa: E501
        """AccountDetail - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._business_name = None
        self._constitution_date = None
        self._emails = None
        self._legal_representatives = None
        self._rfc = None
        self.discriminator = None
        if address is not None:
            self.address = address
        if business_name is not None:
            self.business_name = business_name
        if constitution_date is not None:
            self.constitution_date = constitution_date
        if emails is not None:
            self.emails = emails
        if legal_representatives is not None:
            self.legal_representatives = legal_representatives
        if rfc is not None:
            self.rfc = rfc

    @property
    def address(self):
        """Gets the address of this AccountDetail.  # noqa: E501


        :return: The address of this AccountDetail.  # noqa: E501
        :rtype: AddressCompany
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this AccountDetail.


        :param address: The address of this AccountDetail.  # noqa: E501
        :type: AddressCompany
        """

        self._address = address

    @property
    def business_name(self):
        """Gets the business_name of this AccountDetail.  # noqa: E501

        El nombre del negocio  # noqa: E501

        :return: The business_name of this AccountDetail.  # noqa: E501
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """Sets the business_name of this AccountDetail.

        El nombre del negocio  # noqa: E501

        :param business_name: The business_name of this AccountDetail.  # noqa: E501
        :type: str
        """

        self._business_name = business_name

    @property
    def constitution_date(self):
        """Gets the constitution_date of this AccountDetail.  # noqa: E501

        La fecha de constitución del negocio  # noqa: E501

        :return: The constitution_date of this AccountDetail.  # noqa: E501
        :rtype: str
        """
        return self._constitution_date

    @constitution_date.setter
    def constitution_date(self, constitution_date):
        """Sets the constitution_date of this AccountDetail.

        La fecha de constitución del negocio  # noqa: E501

        :param constitution_date: The constitution_date of this AccountDetail.  # noqa: E501
        :type: str
        """

        self._constitution_date = constitution_date

    @property
    def emails(self):
        """Gets the emails of this AccountDetail.  # noqa: E501

        La lista de correos del negocio  # noqa: E501

        :return: The emails of this AccountDetail.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this AccountDetail.

        La lista de correos del negocio  # noqa: E501

        :param emails: The emails of this AccountDetail.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def legal_representatives(self):
        """Gets the legal_representatives of this AccountDetail.  # noqa: E501

        La lista de los representantes legales negocio  # noqa: E501

        :return: The legal_representatives of this AccountDetail.  # noqa: E501
        :rtype: list[str]
        """
        return self._legal_representatives

    @legal_representatives.setter
    def legal_representatives(self, legal_representatives):
        """Sets the legal_representatives of this AccountDetail.

        La lista de los representantes legales negocio  # noqa: E501

        :param legal_representatives: The legal_representatives of this AccountDetail.  # noqa: E501
        :type: list[str]
        """

        self._legal_representatives = legal_representatives

    @property
    def rfc(self):
        """Gets the rfc of this AccountDetail.  # noqa: E501

        El RFC del negocio  # noqa: E501

        :return: The rfc of this AccountDetail.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this AccountDetail.

        El RFC del negocio  # noqa: E501

        :param rfc: The rfc of this AccountDetail.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.billing_transaction import BillingTransaction  # noqa: F401,E501


class Billing(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'emission_at': 'datetime',
        'end_date': 'datetime',
        'id': 'str',
        'start_date': 'datetime',
        'status': 'str',
        'transactions': 'list[BillingTransaction]',
        'url_pdf': 'str',
        'url_xml': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'emission_at': 'emission_at',
        'end_date': 'end_date',
        'id': 'id',
        'start_date': 'start_date',
        'status': 'status',
        'transactions': 'transactions',
        'url_pdf': 'url_pdf',
        'url_xml': 'url_xml'
    }

    def __init__(self, amount=None, emission_at=None, end_date=None, id=None, start_date=None, status=None, transactions=None, url_pdf=None, url_xml=None):  # noqa: E501
        """Billing - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._emission_at = None
        self._end_date = None
        self._id = None
        self._start_date = None
        self._status = None
        self._transactions = None
        self._url_pdf = None
        self._url_xml = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if emission_at is not None:
            self.emission_at = emission_at
        if end_date is not None:
            self.end_date = end_date
        if id is not None:
            self.id = id
        if start_date is not None:
            self.start_date = start_date
        if status is not None:
            self.status = status
        if transactions is not None:
            self.transactions = transactions
        if url_pdf is not None:
            self.url_pdf = url_pdf
        if url_xml is not None:
            self.url_xml = url_xml

    @property
    def amount(self):
        """Gets the amount of this Billing.  # noqa: E501

        Monto total de la factura  # noqa: E501

        :return: The amount of this Billing.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Billing.

        Monto total de la factura  # noqa: E501

        :param amount: The amount of this Billing.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def emission_at(self):
        """Gets the emission_at of this Billing.  # noqa: E501

        Fecha y hora en que se emitió de la factura  # noqa: E501

        :return: The emission_at of this Billing.  # noqa: E501
        :rtype: datetime
        """
        return self._emission_at

    @emission_at.setter
    def emission_at(self, emission_at):
        """Sets the emission_at of this Billing.

        Fecha y hora en que se emitió de la factura  # noqa: E501

        :param emission_at: The emission_at of this Billing.  # noqa: E501
        :type: datetime
        """

        self._emission_at = emission_at

    @property
    def end_date(self):
        """Gets the end_date of this Billing.  # noqa: E501

        Fecha en que finaliza el periodo que se factura  # noqa: E501

        :return: The end_date of this Billing.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Billing.

        Fecha en que finaliza el periodo que se factura  # noqa: E501

        :param end_date: The end_date of this Billing.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def id(self):
        """Gets the id of this Billing.  # noqa: E501

        Identificador de la factura  # noqa: E501

        :return: The id of this Billing.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Billing.

        Identificador de la factura  # noqa: E501

        :param id: The id of this Billing.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def start_date(self):
        """Gets the start_date of this Billing.  # noqa: E501

        Fecha de inicio del periodo que se factura  # noqa: E501

        :return: The start_date of this Billing.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Billing.

        Fecha de inicio del periodo que se factura  # noqa: E501

        :param start_date: The start_date of this Billing.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def status(self):
        """Gets the status of this Billing.  # noqa: E501

        Estatus de la factura  # noqa: E501

        :return: The status of this Billing.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Billing.

        Estatus de la factura  # noqa: E501

        :param status: The status of this Billing.  # noqa: E501
        :type: str
        """
        allowed_values = ["PAID", "OMMITED", "WAITING_PAYMENT", "EMISSION_PENDING"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def transactions(self):
        """Gets the transactions of this Billing.  # noqa: E501


        :return: The transactions of this Billing.  # noqa: E501
        :rtype: list[BillingTransaction]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this Billing.


        :param transactions: The transactions of this Billing.  # noqa: E501
        :type: list[BillingTransaction]
        """

        self._transactions = transactions

    @property
    def url_pdf(self):
        """Gets the url_pdf of this Billing.  # noqa: E501

        Url de la representación impresa en pdf de la factura  # noqa: E501

        :return: The url_pdf of this Billing.  # noqa: E501
        :rtype: str
        """
        return self._url_pdf

    @url_pdf.setter
    def url_pdf(self, url_pdf):
        """Sets the url_pdf of this Billing.

        Url de la representación impresa en pdf de la factura  # noqa: E501

        :param url_pdf: The url_pdf of this Billing.  # noqa: E501
        :type: str
        """

        self._url_pdf = url_pdf

    @property
    def url_xml(self):
        """Gets the url_xml of this Billing.  # noqa: E501

        Url del archivo xml de la factura  # noqa: E501

        :return: The url_xml of this Billing.  # noqa: E501
        :rtype: str
        """
        return self._url_xml

    @url_xml.setter
    def url_xml(self, url_xml):
        """Sets the url_xml of this Billing.

        Url del archivo xml de la factura  # noqa: E501

        :param url_xml: The url_xml of this Billing.  # noqa: E501
        :type: str
        """

        self._url_xml = url_xml

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Billing, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Billing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BillingTransaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'clave_rastreo': 'str',
        'monex_id': 'int',
        'operation_date': 'datetime',
        'order_id': 'str',
        'payment_order_id': 'str',
        'transaction_id': 'int',
        'type': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'clave_rastreo': 'clave_rastreo',
        'monex_id': 'monex_id',
        'operation_date': 'operation_date',
        'order_id': 'order_id',
        'payment_order_id': 'payment_order_id',
        'transaction_id': 'transaction_id',
        'type': 'type'
    }

    def __init__(self, amount=None, clave_rastreo=None, monex_id=None, operation_date=None, order_id=None, payment_order_id=None, transaction_id=None, type=None):  # noqa: E501
        """BillingTransaction - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._clave_rastreo = None
        self._monex_id = None
        self._operation_date = None
        self._order_id = None
        self._payment_order_id = None
        self._transaction_id = None
        self._type = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if clave_rastreo is not None:
            self.clave_rastreo = clave_rastreo
        if monex_id is not None:
            self.monex_id = monex_id
        if operation_date is not None:
            self.operation_date = operation_date
        if order_id is not None:
            self.order_id = order_id
        if payment_order_id is not None:
            self.payment_order_id = payment_order_id
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if type is not None:
            self.type = type

    @property
    def amount(self):
        """Gets the amount of this BillingTransaction.  # noqa: E501

        Monto de la transacción  # noqa: E501

        :return: The amount of this BillingTransaction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BillingTransaction.

        Monto de la transacción  # noqa: E501

        :param amount: The amount of this BillingTransaction.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def clave_rastreo(self):
        """Gets the clave_rastreo of this BillingTransaction.  # noqa: E501

        Clave de rastreo que se asignó a la transacción  # noqa: E501

        :return: The clave_rastreo of this BillingTransaction.  # noqa: E501
        :rtype: str
        """
        return self._clave_rastreo

    @clave_rastreo.setter
    def clave_rastreo(self, clave_rastreo):
        """Sets the clave_rastreo of this BillingTransaction.

        Clave de rastreo que se asignó a la transacción  # noqa: E501

        :param clave_rastreo: The clave_rastreo of this BillingTransaction.  # noqa: E501
        :type: str
        """

        self._clave_rastreo = clave_rastreo

    @property
    def monex_id(self):
        """Gets the monex_id of this BillingTransaction.  # noqa: E501

        Identificador de transaccion en banco monex  # noqa: E501

        :return: The monex_id of this BillingTransaction.  # noqa: E501
        :rtype: int
        """
        return self._monex_id

    @monex_id.setter
    def monex_id(self, monex_id):
        """Sets the monex_id of this BillingTransaction.

        Identificador de transaccion en banco monex  # noqa: E501

        :param monex_id: The monex_id of this BillingTransaction.  # noqa: E501
        :type: int
        """

        self._monex_id = monex_id

    @property
    def operation_date(self):
        """Gets the operation_date of this BillingTransaction.  # noqa: E501

        Fecha y hora de la transacción  # noqa: E501

        :return: The operation_date of this BillingTransaction.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this BillingTransaction.

        Fecha y hora de la transacción  # noqa: E501

        :param operation_date: The operation_date of this BillingTransaction.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def order_id(self):
        """Gets the order_id of this BillingTransaction.  # noqa: E501

        Identificador de la orden  # noqa: E501

        :return: The order_id of this BillingTransaction.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this BillingTransaction.

        Identificador de la orden  # noqa: E501

        :param order_id: The order_id of this BillingTransaction.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_order_id(self):
        """Gets the payment_order_id of this BillingTransaction.  # noqa: E501

        Identificador de la orden de pago  # noqa: E501

        :return: The payment_order_id of this BillingTransaction.  # noqa: E501
        :rtype: str
        """
        return self._payment_order_id

    @payment_order_id.setter
    def payment_order_id(self, payment_order_id):
        """Sets the payment_order_id of this BillingTransaction.

        Identificador de la orden de pago  # noqa: E501

        :param payment_order_id: The payment_order_id of this BillingTransaction.  # noqa: E501
        :type: str
        """

        self._payment_order_id = payment_order_id

    @property
    def transaction_id(self):
        """Gets the transaction_id of this BillingTransaction.  # noqa: E501

        Identificador de la transacción  # noqa: E501

        :return: The transaction_id of this BillingTransaction.  # noqa: E501
        :rtype: int
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this BillingTransaction.

        Identificador de la transacción  # noqa: E501

        :param transaction_id: The transaction_id of this BillingTransaction.  # noqa: E501
        :type: int
        """

        self._transaction_id = transaction_id

    @property
    def type(self):
        """Gets the type of this BillingTransaction.  # noqa: E501

        Tipo de transaccion IN | OUT  # noqa: E501

        :return: The type of this BillingTransaction.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BillingTransaction.

        Tipo de transaccion IN | OUT  # noqa: E501

        :param type: The type of this BillingTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN", "OUT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AddressCompany(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'country_code': 'str',
        'exterior_number': 'str',
        'interior_number': 'str',
        'municipality': 'str',
        'postal_code': 'str',
        'settlement': 'str',
        'settlement_name': 'str',
        'state': 'str',
        'street_address': 'str'
    }

    attribute_map = {
        'city': 'city',
        'country_code': 'country_code',
        'exterior_number': 'exterior_number',
        'interior_number': 'interior_number',
        'municipality': 'municipality',
        'postal_code': 'postal_code',
        'settlement': 'settlement',
        'settlement_name': 'settlement_name',
        'state': 'state',
        'street_address': 'street_address'
    }

    def __init__(self, city=None, country_code=None, exterior_number=None, interior_number=None, municipality=None, postal_code=None, settlement=None, settlement_name=None, state=None, street_address=None):  # noqa: E501
        """AddressCompany - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._country_code = None
        self._exterior_number = None
        self._interior_number = None
        self._municipality = None
        self._postal_code = None
        self._settlement = None
        self._settlement_name = None
        self._state = None
        self._street_address = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if country_code is not None:
            self.country_code = country_code
        if exterior_number is not None:
            self.exterior_number = exterior_number
        if interior_number is not None:
            self.interior_number = interior_number
        if municipality is not None:
            self.municipality = municipality
        if postal_code is not None:
            self.postal_code = postal_code
        if settlement is not None:
            self.settlement = settlement
        if settlement_name is not None:
            self.settlement_name = settlement_name
        if state is not None:
            self.state = state
        if street_address is not None:
            self.street_address = street_address

    @property
    def city(self):
        """Gets the city of this AddressCompany.  # noqa: E501

        La ciudad  # noqa: E501

        :return: The city of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this AddressCompany.

        La ciudad  # noqa: E501

        :param city: The city of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def country_code(self):
        """Gets the country_code of this AddressCompany.  # noqa: E501

        La clabe del país  # noqa: E501

        :return: The country_code of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this AddressCompany.

        La clabe del país  # noqa: E501

        :param country_code: The country_code of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def exterior_number(self):
        """Gets the exterior_number of this AddressCompany.  # noqa: E501

        Número exterior  # noqa: E501

        :return: The exterior_number of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._exterior_number

    @exterior_number.setter
    def exterior_number(self, exterior_number):
        """Sets the exterior_number of this AddressCompany.

        Número exterior  # noqa: E501

        :param exterior_number: The exterior_number of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._exterior_number = exterior_number

    @property
    def interior_number(self):
        """Gets the interior_number of this AddressCompany.  # noqa: E501

        Número interior  # noqa: E501

        :return: The interior_number of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._interior_number

    @interior_number.setter
    def interior_number(self, interior_number):
        """Sets the interior_number of this AddressCompany.

        Número interior  # noqa: E501

        :param interior_number: The interior_number of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._interior_number = interior_number

    @property
    def municipality(self):
        """Gets the municipality of this AddressCompany.  # noqa: E501

        El municipio  # noqa: E501

        :return: The municipality of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._municipality

    @municipality.setter
    def municipality(self, municipality):
        """Sets the municipality of this AddressCompany.

        El municipio  # noqa: E501

        :param municipality: The municipality of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._municipality = municipality

    @property
    def postal_code(self):
        """Gets the postal_code of this AddressCompany.  # noqa: E501

        Código postal  # noqa: E501

        :return: The postal_code of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this AddressCompany.

        Código postal  # noqa: E501

        :param postal_code: The postal_code of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def settlement(self):
        """Gets the settlement of this AddressCompany.  # noqa: E501

        El asentamiento  # noqa: E501

        :return: The settlement of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._settlement

    @settlement.setter
    def settlement(self, settlement):
        """Sets the settlement of this AddressCompany.

        El asentamiento  # noqa: E501

        :param settlement: The settlement of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._settlement = settlement

    @property
    def settlement_name(self):
        """Gets the settlement_name of this AddressCompany.  # noqa: E501

        El nombre del asentamiento  # noqa: E501

        :return: The settlement_name of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._settlement_name

    @settlement_name.setter
    def settlement_name(self, settlement_name):
        """Sets the settlement_name of this AddressCompany.

        El nombre del asentamiento  # noqa: E501

        :param settlement_name: The settlement_name of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._settlement_name = settlement_name

    @property
    def state(self):
        """Gets the state of this AddressCompany.  # noqa: E501

        El estado  # noqa: E501

        :return: The state of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AddressCompany.

        El estado  # noqa: E501

        :param state: The state of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def street_address(self):
        """Gets the street_address of this AddressCompany.  # noqa: E501

        La calle  # noqa: E501

        :return: The street_address of this AddressCompany.  # noqa: E501
        :rtype: str
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this AddressCompany.

        La calle  # noqa: E501

        :param street_address: The street_address of this AddressCompany.  # noqa: E501
        :type: str
        """

        self._street_address = street_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddressCompany, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressCompany):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from wire4_client.models.account import Account
from wire4_client.models.account_detail import AccountDetail
from wire4_client.models.account_reassigned import AccountReassigned
from wire4_client.models.account_request import AccountRequest
from wire4_client.models.account_response import AccountResponse
from wire4_client.models.account_spid import AccountSpid
from wire4_client.models.address_company import AddressCompany
from wire4_client.models.amount_request import AmountRequest
from wire4_client.models.authorization_transaction_group import AuthorizationTransactionGroup
from wire4_client.models.authorized_beneficiaries_response import AuthorizedBeneficiariesResponse
from wire4_client.models.authorized_users import AuthorizedUsers
from wire4_client.models.balance import Balance
from wire4_client.models.balance_list_response import BalanceListResponse
from wire4_client.models.beneficiaries_query_register_status import BeneficiariesQueryRegisterStatus
from wire4_client.models.beneficiaries_response import BeneficiariesResponse
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution
from wire4_client.models.billing import Billing
from wire4_client.models.billing_transaction import BillingTransaction
from wire4_client.models.cep_response import CepResponse
from wire4_client.models.cep_search_banxico import CepSearchBanxico
from wire4_client.models.certificate_request import CertificateRequest
from wire4_client.models.codi_code_qr_response_dto import CodiCodeQrResponseDTO
from wire4_client.models.codi_code_request_dto import CodiCodeRequestDTO
from wire4_client.models.codi_operation_response_dto import CodiOperationResponseDTO
from wire4_client.models.codi_operations_filters_request_dto import CodiOperationsFiltersRequestDTO
from wire4_client.models.company_registered import CompanyRegistered
from wire4_client.models.company_requested import CompanyRequested
from wire4_client.models.compay import Compay
from wire4_client.models.configurations_limits import ConfigurationsLimits
from wire4_client.models.contact_request import ContactRequest
from wire4_client.models.contract_detail_request import ContractDetailRequest
from wire4_client.models.contract_detail_response import ContractDetailResponse
from wire4_client.models.deposit import Deposit
from wire4_client.models.deposit_authorization_request import DepositAuthorizationRequest
from wire4_client.models.depositant import Depositant
from wire4_client.models.depositants_register import DepositantsRegister
from wire4_client.models.depositant_count_response import DepositantCountResponse
from wire4_client.models.depositants_response import DepositantsResponse
from wire4_client.models.deposits_authorization_response import DepositsAuthorizationResponse
from wire4_client.models.detailed_error_response import DetailedErrorResponse
from wire4_client.models.error_response import ErrorResponse
from wire4_client.models.get_depositants import GetDepositants
from wire4_client.models.institution import Institution
from wire4_client.models.institutions_list import InstitutionsList
from wire4_client.models.item import Item
from wire4_client.models.message_account_beneficiary import MessageAccountBeneficiary
from wire4_client.models.message_cep import MessageCEP
from wire4_client.models.message_codi_action import MessageCodiAction
from wire4_client.models.message_configurations_limits import MessageConfigurationsLimits
from wire4_client.models.message_deposit_authorization_request import MessageDepositAuthorizationRequest
from wire4_client.models.message_deposit_received import MessageDepositReceived
from wire4_client.models.message_institution import MessageInstitution
from wire4_client.models.message_payment import MessagePayment
from wire4_client.models.message_payment_state_pending import MessagePaymentStatePending
from wire4_client.models.message_request_changed import MessageRequestChanged
from wire4_client.models.message_sales_point import MessageSalesPoint
from wire4_client.models.message_subscription import MessageSubscription
from wire4_client.models.message_user_authorized import MessageUserAuthorized
from wire4_client.models.message_web_hook import MessageWebHook
from wire4_client.models.operations import Operations
from wire4_client.models.pager_response_dto import PagerResponseDto
from wire4_client.models.payment import Payment
from wire4_client.models.payment_codi import PaymentCODI
from wire4_client.models.payment_request_codi_response_dto import PaymentRequestCodiResponseDTO
from wire4_client.models.payments_request_id import PaymentsRequestId
from wire4_client.models.person import Person
from wire4_client.models.pre_enrollment_data import PreEnrollmentData
from wire4_client.models.pre_enrollment_response import PreEnrollmentResponse
from wire4_client.models.pre_monex_authorization import PreMonexAuthorization
from wire4_client.models.relationship import Relationship
from wire4_client.models.relationships_response import RelationshipsResponse
from wire4_client.models.sales_point import SalesPoint
from wire4_client.models.sales_point_found import SalesPointFound
from wire4_client.models.sales_point_request import SalesPointRequest
from wire4_client.models.sales_point_respose import SalesPointRespose
from wire4_client.models.service_banking import ServiceBanking
from wire4_client.models.spid_beneficiaries_response import SpidBeneficiariesResponse
from wire4_client.models.spid_beneficiary_response import SpidBeneficiaryResponse
from wire4_client.models.spid_classification_dto import SpidClassificationDTO
from wire4_client.models.spid_classifications_response_dto import SpidClassificationsResponseDTO
from wire4_client.models.subscription_change_status_request import SubscriptionChangeStatusRequest
from wire4_client.models.token_required_response import TokenRequiredResponse
from wire4_client.models.transaction_error_code import TransactionErrorCode
from wire4_client.models.transaction_outgoing import TransactionOutgoing
from wire4_client.models.transaction_outgoing_spid import TransactionOutgoingSpid
from wire4_client.models.transactions_outgoing_register import TransactionsOutgoingRegister
from wire4_client.models.update_configurations_request_dto import UpdateConfigurationsRequestDTO
from wire4_client.models.urls_redirect import UrlsRedirect
from wire4_client.models.use_service_banking import UseServiceBanking
from wire4_client.models.user_company import UserCompany
from wire4_client.models.web_hook_deposit_authorization_request import WebHookDepositAuthorizationRequest
from wire4_client.models.web_hook_deposit_authorization_response import WebHookDepositAuthorizationResponse
from wire4_client.models.webhook import Webhook
from wire4_client.models.webhook_request import WebhookRequest
from wire4_client.models.webhook_response import WebhookResponse
from wire4_client.models.webhooks_list import WebhooksList



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.webhook import Webhook  # noqa: F401,E501


class SalesPointRespose(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sales_point_id': 'str',
        'user_key': 'str',
        'user_secret': 'str',
        'webhook': 'Webhook'
    }

    attribute_map = {
        'sales_point_id': 'sales_point_id',
        'user_key': 'user_key',
        'user_secret': 'user_secret',
        'webhook': 'webhook'
    }

    def __init__(self, sales_point_id=None, user_key=None, user_secret=None, webhook=None):  # noqa: E501
        """SalesPointRespose - a model defined in Swagger"""  # noqa: E501
        self._sales_point_id = None
        self._user_key = None
        self._user_secret = None
        self._webhook = None
        self.discriminator = None
        if sales_point_id is not None:
            self.sales_point_id = sales_point_id
        if user_key is not None:
            self.user_key = user_key
        if user_secret is not None:
            self.user_secret = user_secret
        if webhook is not None:
            self.webhook = webhook

    @property
    def sales_point_id(self):
        """Gets the sales_point_id of this SalesPointRespose.  # noqa: E501

        Es el identificador del punto de venta.  # noqa: E501

        :return: The sales_point_id of this SalesPointRespose.  # noqa: E501
        :rtype: str
        """
        return self._sales_point_id

    @sales_point_id.setter
    def sales_point_id(self, sales_point_id):
        """Sets the sales_point_id of this SalesPointRespose.

        Es el identificador del punto de venta.  # noqa: E501

        :param sales_point_id: The sales_point_id of this SalesPointRespose.  # noqa: E501
        :type: str
        """

        self._sales_point_id = sales_point_id

    @property
    def user_key(self):
        """Gets the user_key of this SalesPointRespose.  # noqa: E501

        Es la llave de usuario para el API Wire4. Sólo para el uso de CODI®.  # noqa: E501

        :return: The user_key of this SalesPointRespose.  # noqa: E501
        :rtype: str
        """
        return self._user_key

    @user_key.setter
    def user_key(self, user_key):
        """Sets the user_key of this SalesPointRespose.

        Es la llave de usuario para el API Wire4. Sólo para el uso de CODI®.  # noqa: E501

        :param user_key: The user_key of this SalesPointRespose.  # noqa: E501
        :type: str
        """

        self._user_key = user_key

    @property
    def user_secret(self):
        """Gets the user_secret of this SalesPointRespose.  # noqa: E501

        Es la contraseña para el API Wire4. Sólo para el uso de CODI®.  # noqa: E501

        :return: The user_secret of this SalesPointRespose.  # noqa: E501
        :rtype: str
        """
        return self._user_secret

    @user_secret.setter
    def user_secret(self, user_secret):
        """Sets the user_secret of this SalesPointRespose.

        Es la contraseña para el API Wire4. Sólo para el uso de CODI®.  # noqa: E501

        :param user_secret: The user_secret of this SalesPointRespose.  # noqa: E501
        :type: str
        """

        self._user_secret = user_secret

    @property
    def webhook(self):
        """Gets the webhook of this SalesPointRespose.  # noqa: E501


        :return: The webhook of this SalesPointRespose.  # noqa: E501
        :rtype: Webhook
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this SalesPointRespose.


        :param webhook: The webhook of this SalesPointRespose.  # noqa: E501
        :type: Webhook
        """

        self._webhook = webhook

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesPointRespose, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesPointRespose):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "wire4-client"
VERSION = "1.1.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Wire4RestAPI",
    author_email="",
    url="",
    keywords=["Swagger", "Wire4RestAPI"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Referencia de la API de Wire4  # noqa: E501
    """
)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Compay(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commercial_name': 'str',
        'company_id': 'str',
        'name': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'commercial_name': 'commercial_name',
        'company_id': 'company_id',
        'name': 'name',
        'rfc': 'rfc'
    }

    def __init__(self, commercial_name=None, company_id=None, name=None, rfc=None):  # noqa: E501
        """Compay - a model defined in Swagger"""  # noqa: E501
        self._commercial_name = None
        self._company_id = None
        self._name = None
        self._rfc = None
        self.discriminator = None
        if commercial_name is not None:
            self.commercial_name = commercial_name
        if company_id is not None:
            self.company_id = company_id
        if name is not None:
            self.name = name
        if rfc is not None:
            self.rfc = rfc

    @property
    def commercial_name(self):
        """Gets the commercial_name of this Compay.  # noqa: E501

        Nombre comercial de la empresa  # noqa: E501

        :return: The commercial_name of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._commercial_name

    @commercial_name.setter
    def commercial_name(self, commercial_name):
        """Sets the commercial_name of this Compay.

        Nombre comercial de la empresa  # noqa: E501

        :param commercial_name: The commercial_name of this Compay.  # noqa: E501
        :type: str
        """

        self._commercial_name = commercial_name

    @property
    def company_id(self):
        """Gets the company_id of this Compay.  # noqa: E501

        Identificador de la empresa  # noqa: E501

        :return: The company_id of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this Compay.

        Identificador de la empresa  # noqa: E501

        :param company_id: The company_id of this Compay.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def name(self):
        """Gets the name of this Compay.  # noqa: E501

        Nombre de la empresa  # noqa: E501

        :return: The name of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Compay.

        Nombre de la empresa  # noqa: E501

        :param name: The name of this Compay.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rfc(self):
        """Gets the rfc of this Compay.  # noqa: E501

        RFC de la empresa  # noqa: E501

        :return: The rfc of this Compay.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this Compay.

        RFC de la empresa  # noqa: E501

        :param rfc: The rfc of this Compay.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Compay, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Compay):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CodiOperationsFiltersRequestDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_from': 'float',
        'amount_to': 'float',
        'operation_date_from': 'date',
        'operation_date_to': 'date',
        'order_id': 'str',
        'request_date_from': 'date',
        'request_date_to': 'date',
        'status': 'str'
    }

    attribute_map = {
        'amount_from': 'amount_from',
        'amount_to': 'amount_to',
        'operation_date_from': 'operation_date_from',
        'operation_date_to': 'operation_date_to',
        'order_id': 'order_id',
        'request_date_from': 'request_date_from',
        'request_date_to': 'request_date_to',
        'status': 'status'
    }

    def __init__(self, amount_from=None, amount_to=None, operation_date_from=None, operation_date_to=None, order_id=None, request_date_from=None, request_date_to=None, status=None):  # noqa: E501
        """CodiOperationsFiltersRequestDTO - a model defined in Swagger"""  # noqa: E501
        self._amount_from = None
        self._amount_to = None
        self._operation_date_from = None
        self._operation_date_to = None
        self._order_id = None
        self._request_date_from = None
        self._request_date_to = None
        self._status = None
        self.discriminator = None
        if amount_from is not None:
            self.amount_from = amount_from
        if amount_to is not None:
            self.amount_to = amount_to
        if operation_date_from is not None:
            self.operation_date_from = operation_date_from
        if operation_date_to is not None:
            self.operation_date_to = operation_date_to
        if order_id is not None:
            self.order_id = order_id
        if request_date_from is not None:
            self.request_date_from = request_date_from
        if request_date_to is not None:
            self.request_date_to = request_date_to
        if status is not None:
            self.status = status

    @property
    def amount_from(self):
        """Gets the amount_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el monto minimo. Se permiten dos decimales. Ejemplo 1000.00  # noqa: E501

        :return: The amount_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: float
        """
        return self._amount_from

    @amount_from.setter
    def amount_from(self, amount_from):
        """Sets the amount_from of this CodiOperationsFiltersRequestDTO.

        Es el monto minimo. Se permiten dos decimales. Ejemplo 1000.00  # noqa: E501

        :param amount_from: The amount_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: float
        """

        self._amount_from = amount_from

    @property
    def amount_to(self):
        """Gets the amount_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el monto máximo. Se permiten dos decimales. Ejemplo 1000.00  # noqa: E501

        :return: The amount_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: float
        """
        return self._amount_to

    @amount_to.setter
    def amount_to(self, amount_to):
        """Sets the amount_to of this CodiOperationsFiltersRequestDTO.

        Es el monto máximo. Se permiten dos decimales. Ejemplo 1000.00  # noqa: E501

        :param amount_to: The amount_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: float
        """

        self._amount_to = amount_to

    @property
    def operation_date_from(self):
        """Gets the operation_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el filtro de fecha de operación \"desde\".  # noqa: E501

        :return: The operation_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: date
        """
        return self._operation_date_from

    @operation_date_from.setter
    def operation_date_from(self, operation_date_from):
        """Sets the operation_date_from of this CodiOperationsFiltersRequestDTO.

        Es el filtro de fecha de operación \"desde\".  # noqa: E501

        :param operation_date_from: The operation_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: date
        """

        self._operation_date_from = operation_date_from

    @property
    def operation_date_to(self):
        """Gets the operation_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el filtro de fecha de operación \"hasta\".  # noqa: E501

        :return: The operation_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: date
        """
        return self._operation_date_to

    @operation_date_to.setter
    def operation_date_to(self, operation_date_to):
        """Sets the operation_date_to of this CodiOperationsFiltersRequestDTO.

        Es el filtro de fecha de operación \"hasta\".  # noqa: E501

        :param operation_date_to: The operation_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: date
        """

        self._operation_date_to = operation_date_to

    @property
    def order_id(self):
        """Gets the order_id of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el order id de la petición.  # noqa: E501

        :return: The order_id of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this CodiOperationsFiltersRequestDTO.

        Es el order id de la petición.  # noqa: E501

        :param order_id: The order_id of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def request_date_from(self):
        """Gets the request_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el filtro de fecha de petición \"desde\".  # noqa: E501

        :return: The request_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: date
        """
        return self._request_date_from

    @request_date_from.setter
    def request_date_from(self, request_date_from):
        """Sets the request_date_from of this CodiOperationsFiltersRequestDTO.

        Es el filtro de fecha de petición \"desde\".  # noqa: E501

        :param request_date_from: The request_date_from of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: date
        """

        self._request_date_from = request_date_from

    @property
    def request_date_to(self):
        """Gets the request_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el filtro de fecha de petición \"hasta\".  # noqa: E501

        :return: The request_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: date
        """
        return self._request_date_to

    @request_date_to.setter
    def request_date_to(self, request_date_to):
        """Sets the request_date_to of this CodiOperationsFiltersRequestDTO.

        Es el filtro de fecha de petición \"hasta\".  # noqa: E501

        :param request_date_to: The request_date_to of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: date
        """

        self._request_date_to = request_date_to

    @property
    def status(self):
        """Gets the status of this CodiOperationsFiltersRequestDTO.  # noqa: E501

        Es el estado (estatus) de la petición.  # noqa: E501

        :return: The status of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CodiOperationsFiltersRequestDTO.

        Es el estado (estatus) de la petición.  # noqa: E501

        :param status: The status of this CodiOperationsFiltersRequestDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["RECEIVED", "COMPLETED", "CANCELLED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CodiOperationsFiltersRequestDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodiOperationsFiltersRequestDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CertificateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias': 'str',
        'certificate_number': 'str',
        'check_digit': 'str',
        'cipher_data': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'certificate_number': 'certificate_number',
        'check_digit': 'check_digit',
        'cipher_data': 'cipher_data'
    }

    def __init__(self, alias=None, certificate_number=None, check_digit=None, cipher_data=None):  # noqa: E501
        """CertificateRequest - a model defined in Swagger"""  # noqa: E501
        self._alias = None
        self._certificate_number = None
        self._check_digit = None
        self._cipher_data = None
        self.discriminator = None
        if alias is not None:
            self.alias = alias
        if certificate_number is not None:
            self.certificate_number = certificate_number
        if check_digit is not None:
            self.check_digit = check_digit
        if cipher_data is not None:
            self.cipher_data = cipher_data

    @property
    def alias(self):
        """Gets the alias of this CertificateRequest.  # noqa: E501

        Es el alias del certificado.  # noqa: E501

        :return: The alias of this CertificateRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this CertificateRequest.

        Es el alias del certificado.  # noqa: E501

        :param alias: The alias of this CertificateRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def certificate_number(self):
        """Gets the certificate_number of this CertificateRequest.  # noqa: E501

        Es el número de certificado.  # noqa: E501

        :return: The certificate_number of this CertificateRequest.  # noqa: E501
        :rtype: str
        """
        return self._certificate_number

    @certificate_number.setter
    def certificate_number(self, certificate_number):
        """Sets the certificate_number of this CertificateRequest.

        Es el número de certificado.  # noqa: E501

        :param certificate_number: The certificate_number of this CertificateRequest.  # noqa: E501
        :type: str
        """

        self._certificate_number = certificate_number

    @property
    def check_digit(self):
        """Gets the check_digit of this CertificateRequest.  # noqa: E501

        Es el dígito verificador. Es un sólo dígito.  # noqa: E501

        :return: The check_digit of this CertificateRequest.  # noqa: E501
        :rtype: str
        """
        return self._check_digit

    @check_digit.setter
    def check_digit(self, check_digit):
        """Sets the check_digit of this CertificateRequest.

        Es el dígito verificador. Es un sólo dígito.  # noqa: E501

        :param check_digit: The check_digit of this CertificateRequest.  # noqa: E501
        :type: str
        """

        self._check_digit = check_digit

    @property
    def cipher_data(self):
        """Gets the cipher_data of this CertificateRequest.  # noqa: E501

        Es la información de cifrado.  # noqa: E501

        :return: The cipher_data of this CertificateRequest.  # noqa: E501
        :rtype: str
        """
        return self._cipher_data

    @cipher_data.setter
    def cipher_data(self, cipher_data):
        """Sets the cipher_data of this CertificateRequest.

        Es la información de cifrado.  # noqa: E501

        :param cipher_data: The cipher_data of this CertificateRequest.  # noqa: E501
        :type: str
        """

        self._cipher_data = cipher_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CertificateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertificateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.peticiones_de_pago_por_co_di_api import PeticionesDePagoPorCoDiApi  # noqa: E501
from wire4_client.rest import ApiException


class TestPeticionesDePagoPorCoDiApi(unittest.TestCase):
    """PeticionesDePagoPorCoDiApi unit test stubs"""

    def setUp(self):
        self.api = api.peticiones_de_pago_por_co_di_api.PeticionesDePagoPorCoDiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_consult_codi_request_by_order_id(self):
        """Test case for consult_codi_request_by_order_id

        Consulta información de petición por orderId  # noqa: E501
        """
        pass

    def test_generate_codi_code_qr(self):
        """Test case for generate_codi_code_qr

        Genera código QR  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Balance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'balance': 'float',
        'currency': 'str',
        'currency_code': 'str'
    }

    attribute_map = {
        'balance': 'balance',
        'currency': 'currency',
        'currency_code': 'currency_code'
    }

    def __init__(self, balance=None, currency=None, currency_code=None):  # noqa: E501
        """Balance - a model defined in Swagger"""  # noqa: E501
        self._balance = None
        self._currency = None
        self._currency_code = None
        self.discriminator = None
        if balance is not None:
            self.balance = balance
        if currency is not None:
            self.currency = currency
        if currency_code is not None:
            self.currency_code = currency_code

    @property
    def balance(self):
        """Gets the balance of this Balance.  # noqa: E501

        Es el monto del balance del contrato para la moneda especificada.  # noqa: E501

        :return: The balance of this Balance.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this Balance.

        Es el monto del balance del contrato para la moneda especificada.  # noqa: E501

        :param balance: The balance of this Balance.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def currency(self):
        """Gets the currency of this Balance.  # noqa: E501

        Código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :return: The currency of this Balance.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Balance.

        Código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :param currency: The currency of this Balance.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def currency_code(self):
        """Gets the currency_code of this Balance.  # noqa: E501

        Código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :return: The currency_code of this Balance.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Balance.

        Código de divisa que opera el depositante. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this Balance.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Balance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Balance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.transferencias_spei_api import TransferenciasSPEIApi  # noqa: E501
from wire4_client.rest import ApiException


class TestTransferenciasSPEIApi(unittest.TestCase):
    """TransferenciasSPEIApi unit test stubs"""

    def setUp(self):
        self.api = api.transferencias_spei_api.TransferenciasSPEIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_authorization_transactions_group(self):
        """Test case for create_authorization_transactions_group

        Agrupa transacciones bajo un request_id   # noqa: E501
        """
        pass

    def test_drop_transactions_pending_using_delete(self):
        """Test case for drop_transactions_pending_using_delete

        Eliminación de transferencias SPEI® pendientes  # noqa: E501
        """
        pass

    def test_incoming_spei_transactions_report_using_get(self):
        """Test case for incoming_spei_transactions_report_using_get

        Consulta de transferencias recibidas  # noqa: E501
        """
        pass

    def test_out_comming_spei_request_id_transactions_report_using_get(self):
        """Test case for out_comming_spei_request_id_transactions_report_using_get

        Consulta de transferencias de salida por identificador de petición  # noqa: E501
        """
        pass

    def test_outgoing_spei_transactions_report_using_get(self):
        """Test case for outgoing_spei_transactions_report_using_get

        Consulta de transferencias realizadas  # noqa: E501
        """
        pass

    def test_register_outgoing_spei_transaction_using_post(self):
        """Test case for register_outgoing_spei_transaction_using_post

        Registro de transferencias  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
